#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 http-common
version:              0.8.3.4
visibility:           public
id:                   http-common-0.8.3.4-BC7tWqVDJlA691npwUktyV
key:                  http-common-0.8.3.4-BC7tWqVDJlA691npwUktyV
license:              BSD-3-Clause
copyright:            © 2012-2021 Athae Eredh Siniath and Others
maintainer:           Andrew Cowie <istathar@gmail.com>
author:               Andrew Cowie <istathar@gmail.com>
stability:            experimental
homepage:             https://github.com/aesiniath/http-common
synopsis:             Common types for HTTP clients and servers
description:
    /Overview/

    Base types used by a variety of HTTP clients and servers. See http-streams
    "Network.Http.Client" or pipes-http "Pipes.Http.Client" for full
    documentation. You can import @Network.Http.Types@ if you like, but both
    http-streams and pipes-http re-export this package'\''s types and functions.

category:             Web
abi:                  1e87d66d4a027f22e5a7985cf1f106cc
exposed:              True
exposed-modules:
    Network.Http.Internal Network.Http.RequestBuilder
    Network.Http.Types

import-dirs:          /usr/lib/ghc-9.6.6/site-local/http-common-0.8.3.4
library-dirs:         /usr/lib/ghc-9.6.6/site-local/http-common-0.8.3.4
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/http-common-0.8.3.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-http-common
hs-libraries:         HShttp-common-0.8.3.4-BC7tWqVDJlA691npwUktyV
depends:
    base-4.18.2.1 base64-bytestring-1.2.1.0-7JruMLJLgBF2cqlGBjJEVX
    blaze-builder-0.4.4.1-1osLiMNDaK0LJVibZzd2na bytestring-0.11.5.3
    case-insensitive-1.2.1.0-8beqaZQCG6YFLwD8uR7pTp directory-1.3.8.5
    mtl-2.3.1 network-3.1.4.0-tP2o8Wry2b3nJpuPXPLoR
    random-1.2.1.3-5FoUrrA3875KkJXWnCWBBA text-2.0.2
    transformers-0.6.1.0
    unordered-containers-0.2.20.1-ITIVaOGw28dDFkmcPJu0s3

haddock-interfaces:   /usr/share/doc/haskell-http-common/html/http-common.haddock
haddock-html:         /usr/share/doc/haskell-http-common/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

